@@ -18,6 +18,9 @@ from ducktape.mark import ignore, parametrize
 from ducktape.mark.resource import cluster
 
 
+_flake = False
+
+
 class TestThingy(Test):
     """Fake ducktape test class"""
 
@@ -40,6 +43,11 @@ class TestThingy(Test):
     def test_failure(self):
         raise Exception("This failed")
 
+    def test_flaky(self):
+        global _flake
+        flake, _flake = _flake, not _flake
+        assert flake
+
 
 class ClusterTestThingy(Test):
     """Fake ducktape test class"""
